# Copyright 2022 Met Office and contributors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from CSET.operators import read, filters, constraints


def test_filters_operator():
    """Filter cube and verify."""
    cubes = read.read_cubes("tests/test_data/air_temp.nc")
    constraint = constraints.combine_constraints(
        constraints.generate_stash_constraint("m01s03i236"),
        a=constraints.generate_cell_methods_constraint([]),
    )
    cube = filters.filter_cubes(cubes, constraint)
    assert cube.cell_methods == ()
    expected_cube = "<iris 'Cube' of air_temperature / (K) (time: 3; grid_latitude: 17; grid_longitude: 13)>"
    assert repr(cube) == expected_cube
    # Test for exception when multiple cubes returned.
    constraint = constraints.generate_stash_constraint("m01s03i236")
    except_occurred = False
    try:
        cube = filters.filter_cubes(cubes, constraint)
    except ValueError:
        except_occurred = True
    assert except_occurred
